netapp_ontap.resources.ems_config API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.ems_config`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

The Event Management System (EMS) collects and processes events, and sends notification of the events through various reporting mechanisms. The following endpoints defined under '/support/ems', allow you to query a list of observed events, and configure which events you handle and how you are notified: - /support/ems - /support/ems/events - /support/ems/messages - /support/ems/filters - /support/ems/filters/{name}/rules - /support/ems/filters/{name}/rules/{index} - /support/ems/destinations - /support/ems/destinations/{name}

## Examples

### Configuring an email destination

The following example configures EMS to send a support email when a WAFL event is observed with an error severity.

#### Configure the system-wide email parameters

    # API
    PATCH /support/ems
    # JSON Body
    {
      "mail_from": "administrator@mycompany.com",
      "mail_server": "smtp@mycompany.com"
    }
    # Response
    200 OK

### Configuring a filter with an enclosed rule

    # API
    POST /support/ems/filters
    # JSON Body
    {
      "name": "critical-wafl",
      "rules": [
        {
          "index": 1,
          "type": "include",
          "message_criteria": {
            "name_pattern": "wafl.*",
            "severities": "emergency,error,alert"
          }
        }
      ]
    }
    # Response
    201 Created

### Setting up an email destination

    # API
    POST /support/ems/destinations
    # JSON Body
    {
      "name": "Technician_Email",
      "type": "email",
      "destination": "technician@mycompany.com",
      "filters": [
        { "name" : "critical-wafl" }
      ]
    }
    # Response
    201 Created

## Classes

`class EmsConfig (*args, **kwargs)`

  Allows interaction with EmsConfig objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Methods

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves the EMS configuration.

    ### Related ONTAP commands

    - `event config show`

    ### Learn more

    - `DOC /support/ems`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def patch(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Updates the EMS configuration.

    ### Related ONTAP commands

    - `event config modify`

    ### Learn more

    - `DOC /support/ems`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class EmsConfigSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the EmsConfig object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `links GET`

    The links field of the ems_config.

  `mail_from GET PATCH`

    Mail from

    Example: administrator@mycompany.com

  `mail_server GET PATCH`

    Mail server (SMTP)

    Example: mail@mycompany.com

  `proxy_password PATCH`

    Password for HTTP/HTTPS proxy

    Example: password

  `proxy_url GET PATCH`

    HTTP/HTTPS proxy URL

    Example: https://proxyserver.mycompany.com

  `proxy_user GET PATCH`

    User name for HTTP/HTTPS proxy

    Example: proxy_user